==> huaweicloudsdkcss-3.1.133-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/retry_upgrade_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RetryUpgradeTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'action_id': 'str',
        'retry_mode': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'action_id': 'action_id',
        'retry_mode': 'retry_mode'
    }

    def __init__(self, cluster_id=None, action_id=None, retry_mode=None):
        """RetryUpgradeTaskRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 待重试的集群ID。
        :type cluster_id: str
        :param action_id: 待重试的任务ID。
        :type action_id: str
        :param retry_mode: 当该参数不为空时，终止该任务的影响。当前仅支持abort。
        :type retry_mode: str
        """
        
        

        self._cluster_id = None
        self._action_id = None
        self._retry_mode = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.action_id = action_id
        if retry_mode is not None:
            self.retry_mode = retry_mode

    @property
    def cluster_id(self):
        """Gets the cluster_id of this RetryUpgradeTaskRequest.

        待重试的集群ID。

        :return: The cluster_id of this RetryUpgradeTaskRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this RetryUpgradeTaskRequest.

        待重试的集群ID。

        :param cluster_id: The cluster_id of this RetryUpgradeTaskRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def action_id(self):
        """Gets the action_id of this RetryUpgradeTaskRequest.

        待重试的任务ID。

        :return: The action_id of this RetryUpgradeTaskRequest.
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this RetryUpgradeTaskRequest.

        待重试的任务ID。

        :param action_id: The action_id of this RetryUpgradeTaskRequest.
        :type action_id: str
        """
        self._action_id = action_id

    @property
    def retry_mode(self):
        """Gets the retry_mode of this RetryUpgradeTaskRequest.

        当该参数不为空时，终止该任务的影响。当前仅支持abort。

        :return: The retry_mode of this RetryUpgradeTaskRequest.
        :rtype: str
        """
        return self._retry_mode

    @retry_mode.setter
    def retry_mode(self, retry_mode):
        """Sets the retry_mode of this RetryUpgradeTaskRequest.

        当该参数不为空时，终止该任务的影响。当前仅支持abort。

        :param retry_mode: The retry_mode of this RetryUpgradeTaskRequest.
        :type retry_mode: str
        """
        self._retry_mode = retry_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetryUpgradeTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcss-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcss/v1/model/retry_upgrade_task_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RetryUpgradeTaskRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cluster_id': 'str',
        'action_id': 'str',
        'retry_mode': 'str'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'action_id': 'action_id',
        'retry_mode': 'retry_mode'
    }

    def __init__(self, cluster_id=None, action_id=None, retry_mode=None):
        r"""RetryUpgradeTaskRequest

        The model defined in huaweicloud sdk

        :param cluster_id: 待重试的集群ID。
        :type cluster_id: str
        :param action_id: 待重试的任务ID。
        :type action_id: str
        :param retry_mode: 当该参数不为空时，终止该任务的影响。当前仅支持abort。
        :type retry_mode: str
        """
        
        

        self._cluster_id = None
        self._action_id = None
        self._retry_mode = None
        self.discriminator = None

        self.cluster_id = cluster_id
        self.action_id = action_id
        if retry_mode is not None:
            self.retry_mode = retry_mode

    @property
    def cluster_id(self):
        r"""Gets the cluster_id of this RetryUpgradeTaskRequest.

        待重试的集群ID。

        :return: The cluster_id of this RetryUpgradeTaskRequest.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        r"""Sets the cluster_id of this RetryUpgradeTaskRequest.

        待重试的集群ID。

        :param cluster_id: The cluster_id of this RetryUpgradeTaskRequest.
        :type cluster_id: str
        """
        self._cluster_id = cluster_id

    @property
    def action_id(self):
        r"""Gets the action_id of this RetryUpgradeTaskRequest.

        待重试的任务ID。

        :return: The action_id of this RetryUpgradeTaskRequest.
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        r"""Sets the action_id of this RetryUpgradeTaskRequest.

        待重试的任务ID。

        :param action_id: The action_id of this RetryUpgradeTaskRequest.
        :type action_id: str
        """
        self._action_id = action_id

    @property
    def retry_mode(self):
        r"""Gets the retry_mode of this RetryUpgradeTaskRequest.

        当该参数不为空时，终止该任务的影响。当前仅支持abort。

        :return: The retry_mode of this RetryUpgradeTaskRequest.
        :rtype: str
        """
        return self._retry_mode

    @retry_mode.setter
    def retry_mode(self, retry_mode):
        r"""Sets the retry_mode of this RetryUpgradeTaskRequest.

        当该参数不为空时，终止该任务的影响。当前仅支持abort。

        :param retry_mode: The retry_mode of this RetryUpgradeTaskRequest.
        :type retry_mode: str
        """
        self._retry_mode = retry_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetryUpgradeTaskRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
